<?php
/**
 * Enqueue scripts and styles for theme usage.
 *
 * @package    Scroller
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2014, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/* Enqueue styles & scripts. */
add_action( 'wp_enqueue_scripts', 'tj_enqueue_scripts' );

/* Loads for-ie scripts. */
add_action( 'wp_head', 'tj_ie_scripts', 11 );

/* Inline js. */
add_action( 'wp_head', 'tj_inline_scripts', 10 );

/* Comment reply js */
add_action( 'comment_form_before', 'tj_enqueue_comment_reply_script' );

/**
 * Enqueue styles and scripts.
 *
 * @since 1.0.0
 */
function tj_enqueue_scripts() {

	wp_enqueue_script( 'jquery-ui-tabs' );

	// if WP_DEBUG and/or SCRIPT_DEBUG turned on, load the unminified styles & script.
	if ( WP_DEBUG || SCRIPT_DEBUG ) {

		/* Load main stylesheet. */
		wp_enqueue_style( 'scroller-style', get_stylesheet_uri() );

		/* Load jquery plugins. */
		wp_enqueue_script( 'scroller-jquery-plugins', trailingslashit( get_template_directory_uri() ) . 'js/plugins.js', array( 'jquery' ), null, true );

		/* Load jquery custom plugin. */
		wp_enqueue_script( 'scroller-jquery-custom', trailingslashit( get_template_directory_uri() ) . 'js/jquery.custom.js', array( 'jquery' ), null, true );

	} else {

		// Load main stylesheet
		wp_enqueue_style( 'scroller-style', trailingslashit( get_template_directory_uri() ) . 'style.min.css' );

		// Load custom js plugins.
		wp_enqueue_script( 'scroller-scripts', trailingslashit( get_template_directory_uri() ) . 'js/scroller.min.js', array( 'jquery' ), null, true );

	}

	/* Load the custom stylesheet. */
	wp_enqueue_style( 'scroller-custom', trailingslashit( get_template_directory_uri() ) . 'custom.css', null, null );

	/* Load font-awesome stylesheet. */
	wp_enqueue_style( 'scroller-fontawesome', trailingslashit( get_template_directory_uri() ) . 'css/font-awesome.css', null, null );
	
	/* Load media queries (responsive) stylesheet. */
	if(get_option('scroller_layout') == 'Responsive') {
		wp_enqueue_style( 'scroller-media-queries', trailingslashit( get_template_directory_uri() ) . 'css/media-queries.css', null, null );
	}

	/* Custom variable for jquery. */
	wp_localize_script( 'custom', 'jsobj', array( 'ajaxurl' => admin_url( 'admin-ajax.php' ) ) );

}

/**
 * Loads for-ie scripts.
 * 
 * @since 1.0.0
 */
function tj_ie_scripts() {
?>
<!--[if lt IE 9]>
	<script src="<?php echo get_template_directory_uri(); ?>/js/css3-mediaqueries.js"></script>
	<script src="<?php echo get_template_directory_uri(); ?>/js/html5.js"></script>	
<![endif]-->
<!--[if lt IE 7]>
	<script src="<?php echo get_template_directory_uri(); ?>/css/font-awesome-ie7.min.css"></script>
<![endif]-->
<?php
}

/**
 * Inline Javascripts
 *
 * @since 1.0.0
 */
function tj_inline_scripts() {
?>
<script type="text/javascript">
var $ = jQuery.noConflict();
$(document).ready(function() {

	$("#submit_btn").click(function() { 
		//get input field values
		var user_name       = $('input[name=name]').val(); 
		var user_email      = $('input[name=email]').val();
		var user_phone      = $('input[name=phone]').val();
		var user_message    = $('textarea[name=message]').val();
		
		//simple validation at client's end
		//we simply change border color to red if empty field using .css()
		var proceed = true;
		if(user_name==""){ 
			$('input[name=name]').css('border-color','#FF6666');
			proceed = false;
		}
		if(user_email==""){ 
			$('input[name=email]').css('border-color','#FF6666'); 
			proceed = false;
		}
		if(user_phone=="") {    
			$('input[name=phone]').css('border-color','#FF6666'); 
			proceed = false;
		}
		if(user_message=="") {  
			$('textarea[name=message]').css('border-color','#FF6666'); 
			proceed = false;
		}
		
		//everything looks good! proceed...
		if(proceed) 
		{
			//data to be sent to server
			post_data = {'userName':user_name, 'userEmail':user_email, 'userPhone':user_phone, 'userMessage':user_message};
			
			//Ajax post data to server
			$.post('<?php echo get_template_directory_uri(); ?>/includes/contact-form.php', post_data, function(data){  
				
				//load success massage in #result div element, with slide effect.       
				$("#result").hide().html('<div class="success">'+data+'</div>').slideDown();
				
				//reset values in all input fields
				$('#contact_form input').val(''); 
				$('#contact_form textarea').val(''); 
				
			}).fail(function(err) {  //load any error data
				$("#result").hide().html('<div class="error">'+err.statusText+'</div>').slideDown();
			});
		}
				
	});
	
	//reset previously set border colors and hide all message on .keyup()
	$("#contact_form input, #contact_form textarea").keyup(function() { 
		$("#contact_form input, #contact_form textarea").css('border-color',''); 
		$("#result").slideUp();
	});

	/*-----------------------------------------------------------------------------------*/
	/*  Search Form (Popup)
	/*-----------------------------------------------------------------------------------*/

	$('.header-search > .icon-search').click(function(){
		$('#primary-nav .search-form').fadeIn('', function() {});
		$('.header-search > .icon-search').toggleClass('active');
		$('.header-search > .icon-remove').toggleClass('active');
	});

	$('.header-search > .icon-remove').click(function(){
		$('#primary-nav .search-form').fadeOut('', function() {});
		$('.header-search > .icon-search').toggleClass('active');
		$('.header-search > .icon-remove').toggleClass('active');
	});

	<?php if ( is_home() ) { ?>
	/**
	 * Onepage nave methods.
	 */
	$('#nav').onePageNav({
		filter: ':not(.external a)'
	});
	
	$('.do').click(function(e) {
		e.preventDefault();
	});
	<?php } ?>
	
});
</script>
<?php
}

/**
 * Comment reply js.
 *
 * @since 1.0.0
 */
function tj_enqueue_comment_reply_script() {
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );
}