<?php
/**
 * Various custom functions for theme usage.
 *
 * @package    Scroller
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2014, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/* wp_nav_menu() fallback. */
add_filter( 'wp_page_menu_args', 'tj_menu_args' );

/* Adds custom classes to the body classes. */
add_filter( 'body_class', 'tj_body_classes' );

/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 * 
 * @param  array $args
 * @since  1.0.0
 * @access public
 * @return array
 */
function tj_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}

/**
 * Adds custom classes to the array of body classes.
 *
 * @param  array $classes
 * @since  1.0.0
 * @access public
 * @return array
 */
function tj_body_classes( $classes ) {

	/* Adds a class of group-blog to blogs with more than 1 published author. */
	if ( is_multi_author() )
		$classes[] = 'group-blog';

	return $classes;
}

/**
 * Add custom class to the portfolio items.
 *
 * @since  1.0.0
 * @access public
 */
function tj_terms_class() {

	$terms = get_the_terms( get_the_ID(), 'portfolio-type' );

	if ( is_array( $terms ) ) {
		foreach ( $terms as $term ) {
			echo 'cat-item-'.$term->term_id.' ';
		}
	}

}

/**
 * Custom related portfolio.
 *
 * @since  1.0.0
 * @access public
 */
function tj_related_portfolio() {
	global $post;

	/* Only display related posts on single page. */
	if ( ! is_singular() )
		return;

	/* Get the taxonomy terms of the current page for the specified taxonomy. */
	$terms = wp_get_post_terms( $post->ID, 'portfolio-type', array( 'fields' => 'ids' ) );

	/* Check if the terms exist. */
	if ( empty( $terms ) )
		return;

	/* Query arguments. */
	$query = array(
		'tax_query' => array(
			array(
				'taxonomy' => 'portfolio-type',
				'field'    => 'id',
				'terms'    => $terms,
				'operator' => 'IN'
			)
		),
		'posts_per_page'   => 3,
		'exclude'          => $post->ID,
		'post_type'        => 'portfolio',
	);

	/* Perform the query. */
	$posts = get_posts( $query );

	if ( $posts ) {

		$html = '<div id="portfolio">';

			$html .= '<h1 class="related-title">' . __( 'Related Items', 'junkie' ) . '</h1>';

			$html .= '<ul>';

				foreach( $posts as $post ) {
					setup_postdata( $post );

					/* Get the short description meta box value. */
					$short_desc  = get_post_meta(get_the_ID(), 'tj_portfolio_short_desc', true );

					$html .= '<li class="portfolio-item portfolio-item-3-col">';
						if ( has_post_thumbnail() ) {
							$html .= '<a href="' . esc_url( get_permalink( $post->ID ) ) . '">' . get_the_post_thumbnail( $post->ID, 'scroller-portfolio-3', array( 'class' => 'entry-thumb' ) ) . '</a>';
						}
						$html .= '<div class="entry-details">';
							$html .= '<h1 class="entry-title"><a href="' . esc_url( get_permalink( $post->ID ) ) . '">' . esc_attr( get_the_title() ) . '</a></h1>';
							$html .= '<div class="entry-desc">' . stripslashes( htmlspecialchars_decode( $short_desc ) ) . '</div>';
						$html .= '</div>';
					$html .= '</li>';

				}

			$html .= '</ul>';

		$html .= '</div>';

	}

	if ( isset( $html ) )
		echo $html;

	/* Restore original Post Data. */
	wp_reset_postdata();

}