<?php
/**
 * Various template tags for theme usage.
 *
 * @package    Scroller
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2014, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

if ( ! function_exists( 'tj_paging_nav' ) ) :
/**
 * Display navigation to next/previous set of posts when applicable.
 *
 * @since  1.0.0
 * @access public
 */
function tj_paging_nav() {

	/* Don't print empty markup if there's only one page. */
	if ( $GLOBALS['wp_query']->max_num_pages < 2 ) {
		return;
	}
	?>

	<nav role="navigation" class="navigation paging-navigation">

	    <?php if ( function_exists( 'wp_pagenavi' ) ) wp_pagenavi(); else { ?>

			<div class="nav-links">

				<?php if ( get_next_posts_link() ) : ?>
				<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older Posts', 'junkie' ) ); ?></div>
				<?php endif; ?>

				<?php if ( get_previous_posts_link() ) : ?>
				<div class="nav-next"><?php previous_posts_link( __( 'Newer Posts <span class="meta-nav">&rarr;</span>', 'junkie' ) ); ?></div>
				<?php endif; ?>

			</div><!-- .nav-links -->

	    <?php } ?> 

	</nav><!-- .paging-navigation -->
	<?php
}
endif;

if ( ! function_exists( 'tj_post_nav' ) ) :
/**
 * Display navigation to next/previous post when applicable.
 *
 * @since  1.0.0
 * @access public
 */
function tj_post_nav() {

	/* Don't print empty markup if there's nowhere to navigate. */
	$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
	$next     = get_adjacent_post( false, '', false );

	if ( ! $next && ! $previous ) {
		return;
	}
	?>
	<nav class="navigation post-navigation" role="navigation">
		<div class="nav-links">
			<?php previous_post_link( '<div class="nav-previous">%link</div>', _x( '<span class="meta-nav">&larr;</span> %title', 'Previous post link', 'junkie' ) ); ?>
			<?php next_post_link( '<div class="nav-next">%link</div>', _x( '%title <span class="meta-nav">&rarr;</span>', 'Next post link', 'junkie' ) ); ?>
		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}
endif;

if ( ! function_exists( 'tj_comment' ) ) :
/**
 * Template for comments and pingbacks.
 * 
 * @param  object  $comment
 * @param  array   $args
 * @param  integer $depth
 *
 * @since  1.0.0
 * @access public
 */
function tj_comment( $comment, $args, $depth ) {

	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
	?>
	
	<li class="post pingback">
		<p><?php _e( 'Pingback:', 'junkie' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __( 'Edit', 'junkie' ), '<span class="edit-link">', '</span>' ); ?></p>
	<?php
			break;
		default :
	?>

	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID() ?>">

		<div id="comment-<?php comment_ID(); ?>" class="comment-wrap">

			<?php echo get_avatar( $comment, apply_filters( 'scroller_avatar_size', 48 ) ); ?>

			<div class="comment-author card">
				<?php echo get_comment_author_link(); ?> 
			</div>

			<div class="comment-meta commentmetadata">
				<?php printf( __( '%1$s at %2$s', 'junkie' ), get_comment_date(),  get_comment_time() ) ?>
				<?php edit_comment_link( __( '(Edit)', 'junkie' ),'  ','' ) ?> &middot; 
				<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
			</div>

			<div class="comment-body">

				<?php if ($comment->comment_approved == '0') : ?>
					<em class="moderation"><?php _e( 'Your comment is awaiting moderation.', 'junkie' ) ?></em><br />
				<?php endif; ?>

				<?php comment_text() ?>

			</div>

		</div>

	<?php
			break;
	endswitch;

}
endif;

if ( ! function_exists( 'tj_comment_nav' ) ) :
/**
 * Display navigation to next/previous comments pages when applicable.
 *
 * @since  1.0.0
 * @access public
 */
function tj_comment_nav() {

	if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : ?>

	<nav role="navigation" class="navigation comment-navigation">
		<div class="nav-previous">
			<?php previous_comments_link( __( '&larr; Older Comments', 'junkie' ) ); ?>
		</div>
		<div class="nav-next">
			<?php next_comments_link( __( 'Newer Comments &rarr;', 'junkie' ) ); ?>
		</div>
	</nav>

	<?php endif;
}
endif;

if ( ! function_exists( 'tj_archive_title' ) ) :
/**
 * Archive title.
 *
 * @since  1.0.0
 * @access public
 */
function tj_archive_title() {

	if ( is_category() ) :
		single_cat_title();

	elseif ( is_tag() ) :
		single_tag_title();

	elseif ( is_author() ) :
		printf( __( 'Author: %s', 'junkie' ), '<span class="vcard">' . get_the_author() . '</span>' );

	elseif ( is_day() ) :
		printf( __( 'Day: %s', 'junkie' ), '<span>' . get_the_date() . '</span>' );

	elseif ( is_month() ) :
		printf( __( 'Month: %s', 'junkie' ), '<span>' . get_the_date( _x( 'F Y', 'monthly archives date format', 'junkie' ) ) . '</span>' );

	elseif ( is_year() ) :
		printf( __( 'Year: %s', 'junkie' ), '<span>' . get_the_date( _x( 'Y', 'yearly archives date format', 'junkie' ) ) . '</span>' );

	else :
		_e( 'Archives', 'junkie' );

	endif;

}
endif;