<?php
/**
 * Blog Widget.
 *
 * @package    Scroller
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2014, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * Blog Widget Class.
 *
 * @since  1.0.0
 * @access public
 * @link   https://codex.wordpress.org/Widgets_API
 */
class Tj_Blog_Widget extends WP_Widget {

	/**
	 * Sets up the widgets.
	 */
	function __construct() {

		/* Set up the widget options. */
		$widget_options = array(
			'classname'   => 'blog',
			'description' => __( 'Displays recent posts.', 'junkie' )
		);

		/* Set up the widget control options. */
		$control_options = array(
			'width'  => 400,
			'height' => 350
		);

		/* Create the widget. */
		parent::__construct(
			'blog',                               // $this->id_base
			__( 'Scroller : Blog', 'junkie' ), // $this->name
			$widget_options,                      // $this->widget_options
			$control_options                      // $this->control_options
		);
	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 */
	function widget( $args, $instance ) {
		extract( $args );

		/* Output the theme's $before_widget wrapper. */
		echo $before_widget;
		
		?>

			<section id="blog" class="clearfix">
				<div class="container">
						
					<?php
					/* If a title was input by the user, display it. */
					if ( !empty( $instance['title'] ) )
						echo $before_title . apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base ) . $after_title;
					?>

					<p class="section-description">
						<?php echo stripslashes( $instance['desc'] ); ?>
					</p><!-- .section-description -->

					<div id="recentposts" class="clearfix">
						
						<?php $i = 1; ?>
						<?php $blog =  new WP_Query( array( 'showposts' => $instance['num'], 'sortby' => 'id', 'ignore_sticky_posts' => true ) ); ?>

						<?php if( $blog->have_posts() ) : while( $blog->have_posts() ) : $blog->the_post(); ?>

							<div class="bloglarge <?php if( $i%2==0 ) { echo 'post-even'; } else { echo 'post-odd'; } ?>">

								<?php if ( has_post_thumbnail() ) { the_post_thumbnail( 'scroller-blog', array('class' => 'entry-thumb' ) ); } ?>

								<h1 class="entry-title"><a href="<?php the_permalink()?>" rel="bookmark"><?php the_title(); ?></a></h1>

								<div class="entry-meta">
									by <?php the_author_posts_link(); ?> on <?php the_time('F jS, Y'); ?>
								</div><!-- .entry-meta -->

								<div class="entry-excerpt">
									<?php echo tj_content_limit( 30 ); ?>
								</div>

							</div><!-- .blog-large -->
						
						<?php if( $i%2==0 ) { echo '<div class="clear"></div>'; } ?>
						
						<?php $i++; endwhile; endif; wp_reset_postdata(); ?>

					</div><!-- #recentpost -->
						
					<div class="full-features">
						<a href="<?php echo esc_url( $instance['url'] ); ?>"><?php _e( 'Read more on our Blog', 'junkie' ) ?></a>
					</div><!-- .more-blog -->
					
				</div><!-- .container -->
			</section><!-- #blog -->

		<?php

		/* Close the theme's widget wrapper. */
		echo $after_widget;

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $new_instance;

		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['desc']  = stripslashes( $new_instance['desc'] );
		$instance['num']   = (int) $new_instance['num'];
		$instance['url']   = esc_url_raw( $new_instance['url'] );

		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 */
	function form( $instance ) {

		/* Set up the default form values. */
		$defaults = array(
			'title' => esc_attr__( 'Latest News', 'junkie' ),
			'desc'  => esc_attr__( 'Just an example description for this section', 'junkie' ),
			'num'   => 4,
			'url'   => esc_url( home_url() . '/blog/' )
		);

		/* Merge the user-selected arguments with the defaults. */
		$instance = wp_parse_args( (array) $instance, $defaults );
		?>

		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'junkie' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'desc' ); ?>"><?php _e( 'Description:', 'junkie' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'desc' ); ?>" name="<?php echo $this->get_field_name( 'desc' ); ?>" value="<?php echo esc_attr( $instance['desc'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'num' ); ?>"><?php _e( 'Number of blog posts to show:', 'junkie' ) ?></label>
			<input type="number" step="1" min="1" class="widefat" id="<?php echo $this->get_field_id( 'num' ); ?>" name="<?php echo $this->get_field_name( 'num' ); ?>" value="<?php echo (int) $instance['num']; ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'url' ); ?>"><?php _e( 'Blog URL', 'junkie' ) ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'url' ); ?>" name="<?php echo $this->get_field_name( 'url' ); ?>" value="<?php echo esc_url( $instance['url'] ); ?>" />
		</p>
		
		<?php
	}

}