<?php
/**
 * Contact Widget.
 *
 * @package    Scroller
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2014, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * Contact Widget Class
 *
 * @since  1.0.0
 * @access public
 * @link   https://codex.wordpress.org/Widgets_API
 */
class Tj_Contact_Widget extends WP_Widget {

	/**
	 * Sets up the widgets.
	 */
	function __construct() {

		/* Set up the widget options. */
		$widget_options = array(
			'classname'   => 'contact',
			'description' => __( 'Displays contact form.', 'junkie' )
		);

		/* Set up the widget control options. */
		$control_options = array(
			'width'  => 400,
			'height' => 350
		);

		/* Create the widget. */
		parent::__construct(
			'contact',                               // $this->id_base
			__( 'Scroller : Contact', 'junkie' ), 	 // $this->name
			$widget_options,                         // $this->widget_options
			$control_options                         // $this->control_options
		);
	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 */
	function widget( $args, $instance ) {
		extract( $args );

		/* Output the theme's $before_widget wrapper. */
		echo $before_widget;
		
		?>

		<section id="contact" class="clearfix">
		
			<div class="container">
				
				<?php
				/* If a title was input by the user, display it. */
				if ( !empty( $instance['title'] ) )
					echo $before_title . apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base ) . $after_title;
				?>

				<p class="section-description">
					<?php echo stripslashes( $instance['desc'] ); ?>
				</p><!-- .section-description -->

				<div class="contact-area">
					<div class="contact-left">
						<p><?php echo stripslashes( $instance['extended_desc'] ); ?></p>
						<ul class="contact-info clearfix">
							<li class="phone"><i class="icon-phone"></i> <?php echo esc_attr( $instance['phone'] ); ?></li>
							<li class="email"><i class="icon-envelope"></i> <a href="mailto:<?php echo is_email( $instance['email'] ); ?>"><?php echo is_email( $instance['email'] ); ?></a></li>
							<li class="location"><i class="icon-map-marker"></i> <?php echo stripslashes( $instance['address'] ); ?></li>			
						</ul>
					</div>
					<div class="contact-right">

					<fieldset id="contact_form" class="contact-form">
						<div id="result"></div>
						<div class="col-left">
							<input type="text" name="name" id="name" placeholder="Your Name" />
							<input type="text" name="email" id="email" placeholder="Your Email" />
							<input type="text" name="phone" id="phone" placeholder="Phone Number" />
						</div>
					
						<div class="col-right">
							<textarea name="message" id="message" placeholder="Your Message"></textarea>
							<button class="button-primary" id="submit_btn"><?php _e( 'Send Email', 'junkie' ) ?></button>
						</div>
					</fieldset>

					</div>
					<div class="clear"></div>
				</div><!-- .contact-area -->
				
				<?php echo stripslashes( $instance['map_code'] ); ?>

			</div><!-- .container -->
		</section><!-- #contact -->

		<?php

		/* Close the theme's widget wrapper. */
		echo $after_widget;

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $new_instance;

		$instance['title']         = strip_tags( $new_instance['title'] );
		$instance['desc']          = stripslashes( $new_instance['desc'] );
		$instance['extended_desc'] = stripslashes( $new_instance['extended_desc'] );
		$instance['phone']         = esc_attr( $new_instance['phone'] );
		$instance['email']         = is_email( $new_instance['email'] );
		$instance['address']       = stripslashes( $new_instance['address'] );
		$instance['map_code']      = stripslashes( $new_instance['map_code'] );
		

		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 */
	function form( $instance ) {

		/* Set up the default form values. */
		$defaults = array(
			'title'         => esc_attr__( 'Get In Touch', 'junkie' ),
			'desc'          => esc_attr__( 'Just an example description for this section', 'junkie' ),
			'extended_desc' => esc_attr__( 'Nam ultricies aliquam imperdiet. Pellentesque massa dui, varius non sodales quis, placerat ullamcorper nisl. Donec pulvinar, arcu vel rhoncus commodo, neque lectus blandit elit, vel iaculis odio lectus sit amet metus.', 'junkie' ),
			'phone'         => '1 (888) 350-1688',
			'email'         => 'support@yoursite.com',
			'address'       => '1600 Amphitheatre Parkway, Mountain View, CA 94043',
			'map_code'      => '<img src="'.get_template_directory_uri().'/images/map.png" alt="Map" />'
		);

		/* Merge the user-selected arguments with the defaults. */
		$instance = wp_parse_args( (array) $instance, $defaults );
		?>

		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'junkie' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'desc' ); ?>"><?php _e( 'Description:', 'junkie' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'desc' ); ?>" name="<?php echo $this->get_field_name( 'desc' ); ?>" value="<?php echo esc_attr( $instance['desc'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'extended_desc' ); ?>"><?php _e( 'Extended Description', 'junkie' ); ?></label>
			<textarea class="widefat" id="<?php echo $this->get_field_id( 'extended_desc' ); ?>" name="<?php echo $this->get_field_name( 'extended_desc' ); ?>" rows="6" ><?php echo stripslashes( $instance['extended_desc'] ); ?></textarea>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'phone' ); ?>"><?php _e( 'Phone:', 'junkie' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'phone' ); ?>" name="<?php echo $this->get_field_name( 'phone' ); ?>" value="<?php echo esc_attr( $instance['phone'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'email' ); ?>"><?php _e( 'Email:', 'junkie' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'email' ); ?>" name="<?php echo $this->get_field_name( 'email' ); ?>" value="<?php echo is_email( $instance['email'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'address' ); ?>"><?php _e( 'Address:', 'junkie' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'address' ); ?>" name="<?php echo $this->get_field_name( 'address' ); ?>" value="<?php echo esc_attr( $instance['address'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'map_code' ); ?>"><?php _e( 'Map Code', 'junkie' ); ?></label>
			<textarea class="widefat" id="<?php echo $this->get_field_id( 'map_code' ); ?>" name="<?php echo $this->get_field_name( 'map_code' ); ?>" rows="6" ><?php echo stripslashes( $instance['map_code'] ); ?></textarea>
		</p>		
		
		<?php
	}

}