<?php
/**
 * Feature Widget.
 *
 * @package    Scroller
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2014, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * Feature Widget Class
 *
 * @since  1.0.0
 * @access public
 * @link   https://codex.wordpress.org/Widgets_API
 */
class Tj_Feature_Widget extends WP_Widget {

	/**
	 * Sets up the widgets.
	 */
	function __construct() {

		/* Set up the widget options. */
		$widget_options = array(
			'classname'   => 'feature',
			'description' => __( 'Display custom post type - features.', 'junkie' )
		);

		/* Set up the widget control options. */
		$control_options = array(
			'width'  => 400,
			'height' => 350
		);

		/* Create the widget. */
		parent::__construct(
			'feature',                             // $this->id_base
			__( 'Scroller : Features', 'junkie' ), // $this->name
			$widget_options,                       // $this->widget_options
			$control_options                       // $this->control_options
		);
	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 */
	function widget( $args, $instance ) {
		extract( $args );

		/* Output the theme's $before_widget wrapper. */
		echo $before_widget;

		?>

			<section id="features" class="container clearfix">
			 
				<?php
				/* If a title was input by the user, display it. */
				if ( !empty( $instance['title'] ) )
					echo $before_title . apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base ) . $after_title;
				?>

				<p class="section-description"><?php echo stripslashes( $instance['desc'] ); ?></p>
				
				<?php
				$feature_query = new WP_Query( array( 'post_type' => 'feature', 'showposts' => $instance['num'] ) );
					$i =0;
				if( $feature_query->have_posts() ) : while( $feature_query->have_posts() ) : $feature_query->the_post();
					$i++;
					$feature_icon = get_post_meta( get_the_ID(), 'tj_feature_icon', true );
					$more_link    = get_post_meta( get_the_ID(), 'tj_feature_more_link', true );
				?>

					<div class="feature <?php if($i%3 == 0) { echo "feature-last"; } ?>">
						<img src="<?php echo esc_url( $feature_icon ); ?>" alt="<?php esc_attr( the_title_attribute() ); ?>" class="entry-thumb" />
						<h3 class="feature-title"><?php the_title(); ?></h3>
						<div class="feature-description">
							<?php the_excerpt(); ?>
							<p class="full-features"><a href="<?php echo esc_url( $more_link ); ?>"><?php _e( 'Read more', 'junkie' ); ?></a></p>
						</div><!-- .feature-description -->

					</div><!-- .feature -->
				
					<?php if ( ( $i%3 == 0 ) && $i < $instance['num'] ) { ?>
						<div class="clear"></div>
					<?php } ?>
					
				<?php endwhile; endif; wp_reset_postdata(); ?>
				
			</section><!-- #features -->

		<?php	

		/* Close the theme's widget wrapper. */
		echo $after_widget;

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $new_instance;

		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['desc']  = stripslashes( $new_instance['desc'] );
		$instance['num']   = (int) $new_instance['num'];

		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 */
	function form( $instance ) {

		/* Set up the default form values. */
		$defaults = array(
			'title' => esc_attr__( 'Introducing This Theme', 'junkie' ),
			'desc'  => esc_attr__( 'Just an example description for this section', 'junkie' ),
			'num'   => 3
		);

		/* Merge the user-selected arguments with the defaults. */
		$instance = wp_parse_args( (array) $instance, $defaults );
		?>

		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'junkie' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'desc' ); ?>"><?php _e( 'Description:', 'junkie' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'desc' ); ?>" name="<?php echo $this->get_field_name( 'desc' ); ?>" value="<?php echo esc_attr( $instance['desc'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'num' ); ?>"><?php _e( 'Number of features to show:', 'junkie' ) ?></label>
			<input type="number" step="1" min="1" class="widefat" id="<?php echo $this->get_field_id( 'num' ); ?>" name="<?php echo $this->get_field_name( 'num' ); ?>" value="<?php echo (int) $instance['num']; ?>" />
		</p>
		
		<?php
	}

}