<?php
/**
 * Hero Widget.
 *
 * @package    Scroller
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2014, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * Hero Widget Class
 *
 * @since  1.0.0
 * @access public
 * @link   https://codex.wordpress.org/Widgets_API
 */
class Tj_Hero_Widget extends WP_Widget {

	/**
	 * Sets up the widgets.
	 */
	function __construct() {

		/* Set up the widget options. */
		$widget_options = array(
			'classname'   => 'hero',
			'description' => __( 'Displays the hero section.', 'junkie' )
		);

		/* Set up the widget control options. */
		$control_options = array(
			'width'  => 400,
			'height' => 350
		);

		/* Create the widget. */
		parent::__construct(
			'hero',                             // $this->id_base
			__( 'Scroller : Hero', 'junkie' ),  // $this->name
			$widget_options,                    // $this->widget_options
			$control_options                    // $this->control_options
		);
	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 */
	function widget( $args, $instance ) {
		extract( $args );

		/* Output the theme's $before_widget wrapper. */
		echo $before_widget;

			/* Wrapper. */
			echo '<div id="start">';
				
				/* If a title was input by the user, display it. */
				if ( !empty( $instance['title'] ) )
					echo $before_title . apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base ) . $after_title;

				/* Description. */
				echo '<p>' . stripslashes( $instance['desc'] ) . '</p>';

				/* Button 1. */
				echo '<a href="' . esc_url( $instance['button1_url'] ) . '" class="button-primary">' . esc_attr( $instance['button1_text'] ) . '</a>';

				/* Button 2. */
				echo '<a href="' . esc_url( $instance['button2_url'] ) . '" class="button-secondary">' . esc_attr( $instance['button2_text'] ) . '</a>';
			
			/* Close wrapper */
			echo '</div><!-- #start -->';

		/* Close the theme's widget wrapper. */
		echo $after_widget;

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $new_instance;

		$instance['title']         = strip_tags( $new_instance['title'] );
		$instance['desc']          = stripslashes( $new_instance['desc'] );
		$instance['button1_text']  = esc_attr( $new_instance['button1_text'] );
		$instance['button1_url']   = esc_url_raw( $new_instance['button1_url'] );
		$instance['button2_text']  = esc_attr( $new_instance['button2_text'] );
		$instance['button2_url']   = esc_url_raw( $new_instance['button2_url'] );

		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 */
	function form( $instance ) {

		/* Set up the default form values. */
		$defaults = array(
			'title'         => esc_attr__( 'Better Software, Faster', 'junkie' ),
			'desc'          => esc_attr__( 'Collaborative development for teams of all sizes.', 'junkie' ),
			'button1_text'  => esc_attr__( 'Take a Tour', 'junkie' ),
			'button1_url'   => esc_url( home_url().'/features/' ),
			'button2_text'  => esc_attr__( 'See Our Work', 'junkie' ),
			'button2_url'   => esc_url( home_url().'/portfolio/' )
		);

		/* Merge the user-selected arguments with the defaults. */
		$instance = wp_parse_args( (array) $instance, $defaults );
		?>

		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'junkie' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'desc' ); ?>"><?php _e( 'Description:', 'junkie' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'desc' ); ?>" name="<?php echo $this->get_field_name( 'desc' ); ?>" value="<?php echo esc_attr( $instance['desc'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'button1_text' ); ?>"><?php _e( 'Button1 Text:', 'junkie' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'button1_text' ); ?>" name="<?php echo $this->get_field_name( 'button1_text' ); ?>" value="<?php echo esc_attr( $instance['button1_text'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'button1_url' ); ?>"><?php _e( 'Button1 Link:', 'junkie' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'button1_url' ); ?>" name="<?php echo $this->get_field_name( 'button1_url' ); ?>" value="<?php echo esc_url( $instance['button1_url'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'button2_text' ); ?>"><?php _e( 'Button2 Text:', 'junkie' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'button2_text' ); ?>" name="<?php echo $this->get_field_name( 'button2_text' ); ?>" value="<?php echo esc_attr( $instance['button2_text'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'button2_url' ); ?>"><?php _e( 'Button2 Link:', 'junkie' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'button2_url' ); ?>" name="<?php echo $this->get_field_name( 'button2_url' ); ?>" value="<?php echo esc_url( $instance['button2_url'] ); ?>" />
		</p>

		<?php
	}

}