<?php
/**
 * Portfolio Widget.
 *
 * @package    Scroller
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2014, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * Portolio Widget Class
 *
 * @since  1.0.0
 * @access public
 * @link   https://codex.wordpress.org/Widgets_API
 */
class Tj_Portfolio_Widget extends WP_Widget {

	/**
	 * Sets up the widgets.
	 */
	function __construct() {

		/* Set up the widget options. */
		$widget_options = array(
			'classname'   => 'portfolio',
			'description' => __( 'Displays custom post type - portfolio.', 'junkie' )
		);

		/* Set up the widget control options. */
		$control_options = array(
			'width'  => 400,
			'height' => 350
		);

		/* Create the widget. */
		parent::__construct(
			'portfolio',                            // $this->id_base
			__( 'Scroller : Portfolio', 'junkie' ), // $this->name
			$widget_options,                        // $this->widget_options
			$control_options                        // $this->control_options
		);
	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 */
	function widget( $args, $instance ) {
		extract( $args );

		/* Output the theme's $before_widget wrapper. */
		echo $before_widget;
		
		?>
		
		<section id="work">
			<div class="container">
			
				<?php 
				/* If a title was input by the user, display it. */
				if ( !empty( $instance['title'] ) )
					echo $before_title . apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base ) . $after_title;
				?>

				<p class="section-description">
					<?php echo stripslashes( $instance['desc'] ); ?>
				</p><!-- .section-description -->

				<div class="portfolio-area clearfix">

					<?php $portfolio = new WP_Query( array( 'post_type' => 'portfolio', 'posts_per_page' => $instance['num'] ) ); ?>
					
					<?php if ( $portfolio->have_posts() ) : ?>

						<ul id="foo2">

							<?php $i = 1; ?>
							<?php while ( $portfolio->have_posts() ) : $portfolio->the_post(); ?>
							
							<?php $short_desc = get_post_meta(get_the_ID(), 'tj_portfolio_short_desc', true ); ?>

							<li class="portfolio-item portfolio-item-<?php echo $i; ?> <?php if ( $i%4==0 ) { echo 'portfolio-item-last'; } ?>">
								<a title="<?php the_title(); ?>" href="<?php the_permalink(); ?>"><?php if ( has_post_thumbnail() ) { the_post_thumbnail( 'scroller-portfolio', array('class' => 'entry-thumb') ); } ?></a>
								<h2 class="entry-title"><a title="<?php esc_attr( the_title_attribute() ); ?>" href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h2>
								<p class="portfolio-description"><?php echo stripslashes( $short_desc ); ?></p>
							</li><!-- .portfolio-item -->

							<?php $i++; endwhile;?>
												
						</ul>

					<?php endif; wp_reset_postdata(); ?>

				</div><!-- .portfolio-area -->

				<div class="section-text">
					<a href="<?php echo esc_url( $instance['url'] ); ?>"><?php _e( 'View the Full Portfolio', 'junkie' ) ?></a>
				</div><!-- .section-text -->
			
			</div><!-- .container -->
		</section><!-- #work -->

		<?php

		/* Close the theme's widget wrapper. */
		echo $after_widget;

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $new_instance;

		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['desc']  = stripslashes( $new_instance['desc'] );
		$instance['num']   = (int) $new_instance['num'];
		$instance['url']   = esc_url_raw( $new_instance['url'] );

		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 */
	function form( $instance ) {

		/* Set up the default form values. */
		$defaults = array(
			'title' => esc_attr__( 'See Our Work', 'junkie' ),
			'desc'  => esc_attr__( 'Just an example description for this section', 'junkie' ),
			'num'   => 4,
			'url'   => esc_url( home_url() . '/portfolio/' )
		);

		/* Merge the user-selected arguments with the defaults. */
		$instance = wp_parse_args( (array) $instance, $defaults );
		?>

		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'junkie' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'desc' ); ?>"><?php _e( 'Description:', 'junkie' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'desc' ); ?>" name="<?php echo $this->get_field_name( 'desc' ); ?>" value="<?php echo esc_attr( $instance['desc'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'num' ); ?>"><?php _e( 'Number of portfolio to show:', 'junkie' ) ?></label>
			<input type="number" step="1" min="1" class="widefat" id="<?php echo $this->get_field_id( 'num' ); ?>" name="<?php echo $this->get_field_name( 'num' ); ?>" value="<?php echo (int) $instance['num']; ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'url' ); ?>"><?php _e( 'Portfolio Page URL', 'junkie' ) ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'url' ); ?>" name="<?php echo $this->get_field_name( 'url' ); ?>" value="<?php echo esc_url( $instance['url'] ); ?>" />
		</p>
		
		<?php
	}

}