<?php
/**
 * Team Widget.
 *
 * @package    Scroller
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2014, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * Team Widget Class
 *
 * @since  1.0.0
 * @access public
 * @link   https://codex.wordpress.org/Widgets_API
 */
class Tj_Team_Widget extends WP_Widget {

	/**
	 * Sets up the widgets.
	 */
	function __construct() {

		/* Set up the widget options. */
		$widget_options = array(
			'classname'   => 'team',
			'description' => __( 'Displays custom post type - team.', 'junkie' )
		);

		/* Set up the widget control options. */
		$control_options = array(
			'width'  => 400,
			'height' => 350
		);

		/* Create the widget. */
		parent::__construct(
			'team',                               // $this->id_base
			__( 'Scroller : Team', 'junkie' ), // $this->name
			$widget_options,                      // $this->widget_options
			$control_options                      // $this->control_options
		);
	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 */
	function widget( $args, $instance ) {
		extract( $args );

		/* Output the theme's $before_widget wrapper. */
		echo $before_widget;
		
		?>

		<section id="team">
			<div class="container clearfix">
			
				<?php
				/* If a title was input by the user, display it. */
				if ( !empty( $instance['title'] ) )
					echo $before_title . apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base ) . $after_title;
				?>

				<p class="section-description">
					<?php echo stripslashes( $instance['desc'] ); ?>
				</p><!-- .section-description -->

				<?php 
					$args = array(
						'post_type' => 'member', 
						'showposts' => $instance['num'],
					);
					$team_query = new WP_Query($args);
					$i = 1;

					if ( $team_query->have_posts() ) : while( $team_query->have_posts() ) : $team_query->the_post();
				?>

				<?php
					$member_avatar         = get_post_meta(get_the_ID(), 'tj_member_avatar', true );
					$member_position       = get_post_meta(get_the_ID(), 'tj_member_position', true );
					$member_twitter_url    = get_post_meta(get_the_ID(), 'tj_member_twitter_url', true );
					$member_facebook_url   = get_post_meta(get_the_ID(), 'tj_member_facebook_url', true );
					$member_googleplus_url = get_post_meta(get_the_ID(), 'tj_member_googleplus_url', true );
					$member_linkedin_url   = get_post_meta(get_the_ID(), 'tj_member_linkedin_url', true );
					$member_pinterest_url  = get_post_meta(get_the_ID(), 'tj_member_pinterest_url', true );
				?>
							
					<div class="team-member team-member-<?php echo $i; ?> <?php if ( $i%4 == 0 ) { echo 'team-last'; } ?>">
					
						<img class="entry-thumb" src="<?php echo esc_url( $member_avatar ); ?>" alt="<?php the_title(); ?>" />
						
						<h1 class="entry-title"><?php the_title(); ?></h1>
						
						<div class="member-position">
							<?php echo $member_position; ?>
						</div><!-- .member-position -->
						
						<div class="entry-excerpt">
							<?php echo tj_content_limit( 20 ); ?>
						</div><!-- .entry-excerpt -->
						
						<div class="member-social-icons">
						
							<?php if($member_twitter_url <> '') { ?>
								<a href="<?php echo get_post_meta(get_the_ID(), 'tj_member_twitter_url', true ); ?>"><i class="icon-twitter"></i></a>
							<?php } ?>
							
							<?php if($member_facebook_url <> '') { ?>					
								<a href="<?php echo get_post_meta(get_the_ID(), 'tj_member_facebook_url',  true ); ?>"><i class="icon-facebook"></i></a>
							<?php } ?>
							
							<?php if($member_googleplus_url <> '') { ?>
								<a href="<?php echo get_post_meta(get_the_ID(), 'tj_member_googleplus_url', true ); ?>"><i class="icon-google-plus"></i></a>
							<?php } ?>

							<?php if($member_linkedin_url <> '') { ?>
								<a href="<?php echo get_post_meta(get_the_ID(), 'tj_member_linkedin_url', true ); ?>"><i class="icon-linkedin"></i></a>
							<?php } ?>

							<?php if($member_pinterest_url <> '') { ?>
								<a href="<?php echo get_post_meta(get_the_ID(), 'tj_member_pinterest_url', true ); ?>"><i class="icon-pinterest"></i></a>
							<?php } ?>
											
						</div><!-- .member-social-icons -->
						
					</div><!-- .team-member -->
					
				<?php $i++; endwhile; endif; wp_reset_postdata(); ?>
				
			</div><!-- .container -->
			
		</section><!-- #team -->

		<?php

		/* Close the theme's widget wrapper. */
		echo $after_widget;

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $new_instance;

		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['desc']  = stripslashes( $new_instance['desc'] );
		$instance['num']   = (int) $new_instance['num'];

		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 */
	function form( $instance ) {

		/* Set up the default form values. */
		$defaults = array(
			'title' => esc_attr__( 'Meet The Team', 'junkie' ),
			'desc'  => esc_attr__( 'Just an example description for this section', 'junkie' ),
			'num'   => 4
		);

		/* Merge the user-selected arguments with the defaults. */
		$instance = wp_parse_args( (array) $instance, $defaults );
		?>

		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'junkie' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'desc' ); ?>"><?php _e( 'Description:', 'junkie' ); ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'desc' ); ?>" name="<?php echo $this->get_field_name( 'desc' ); ?>" value="<?php echo esc_attr( $instance['desc'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'num' ); ?>"><?php _e( 'Number of members to show:', 'junkie' ) ?></label>
			<input type="number" step="1" min="1" class="widefat" id="<?php echo $this->get_field_id( 'num' ); ?>" name="<?php echo $this->get_field_name( 'num' ); ?>" value="<?php echo (int) $instance['num']; ?>" />
		</p>
		
		<?php
	}

}