<?php
/**
 * Testimonial Widget.
 *
 * @package    Scroller
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2014, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * Testimonial Widget Class
 *
 * @since  1.0.0
 * @access public
 * @link   https://codex.wordpress.org/Widgets_API
 */
class Tj_Testimonial_Widget extends WP_Widget {

	/**
	 * Sets up the widgets.
	 */
	function __construct() {

		/* Set up the widget options. */
		$widget_options = array(
			'classname'   => 'testimonial',
			'description' => 'Displays custom post type - Testimonial.'
		);

		/* Set up the widget control options. */
		$control_options = array(
			'width'  => 400,
			'height' => 350
		);

		/* Create the widget. */
		parent::__construct(
			'testimonial',                     // $this->id_base
			'Scroller : Testimonial', // $this->name
			$widget_options,                   // $this->widget_options
			$control_options                   // $this->control_options
		);
	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 */
	function widget( $args, $instance ) {
		extract( $args );

		/* Output the theme's $before_widget wrapper. */
		echo $before_widget;
		
		?>
		
			<section id="testimonials" class="clearfix">
				
				<div class="container">

					<?php
					/* If a title was input by the user, display it. */
					if ( !empty( $instance['title'] ) )
						echo $before_title . apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base ) . $after_title;
					?>

					<p class="section-description">
						<?php echo stripslashes( $instance['description'] ); ?>
					</p><!-- .section-description -->

					<?php 
						$args = array(
								'post_type' => 'testimonial', 
								'showposts' => $instance['num'],
							);
						$testimonial_query = new WP_Query( $args );
						$i = 0;

						if($testimonial_query->have_posts()):while($testimonial_query->have_posts()):$testimonial_query->the_post(); 

						$i+=1;

						$testimonial_author_avatar = get_post_meta(get_the_ID(), 'tj_testimonial_author_avatar', true );
						$testimonial_author_name = get_post_meta(get_the_ID(), 'tj_testimonial_author_name', true );
						$testimonial_site_name = get_post_meta(get_the_ID(), 'tj_testimonial_site_name', true );
						$testimonial_site_url = get_post_meta(get_the_ID(), 'tj_testimonial_site_url', true );
						
					?>
					<div class="testimonial <?php if ( $i%3==0 ) { echo 'testimonial-last'; } ?>">
						<blockquote>
							<?php the_content(); ?>
						</blockquote>
						<img src="<?php echo esc_url( $testimonial_author_avatar ); ?>" alt="<?php the_title_attribute(); ?>" class="author-avatar" >			
						<small><?php echo $testimonial_author_name; ?>, <cite><a href="<?php echo $testimonial_site_url; ?>"><?php echo $testimonial_site_name ?></a></cite></small>			
					</div><!-- .testimonial -->
					
					<?php if ( ( $i%3 == 0 ) && $i < $instance['num'] ) { ?>
						<div class="clear"></div>
					<?php } ?>
					
					<?php endwhile; endif; wp_reset_postdata(); ?>

					
				</div><!-- .container -->
				
				<div class="clear"></div>
				
				<div class="client-logos">
					<?php echo $instance['logos']; ?>
				</div><!-- .client-logos -->
				
			</section><!-- #testimonial -->

		<?php
		/* Close the theme's widget wrapper. */
		echo $after_widget;

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $new_instance;

		$instance['title']       = strip_tags( $new_instance['title'] );
		$instance['description'] = stripslashes( $new_instance['description'] );
		$instance['num']         = (int) $new_instance['num'];
		$instance['logos']       = stripslashes( $new_instance['logos'] );

		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 */
	function form( $instance ) {

		/* Set up the default form values. */
		$defaults = array(
			'title'       => 'Happy Clients',
			'description' => 'Just an example description for this section',
			'num'         => 3,
			'logos'       => '<img src="'.get_template_directory_uri().'/images/dribbble.png" alt="Dribbble"/> <img src="'.get_template_directory_uri().'/images/jquery.png" alt="jQuery"/> <img src="'.get_template_directory_uri().'/images/wordpress.png" alt="WordPress"/> <img src="'.get_template_directory_uri().'/images/wpml.png" alt="WPML"/> <img src="'.get_template_directory_uri().'/images/microlancer.png" alt="Microlancer"/>'
		);

		/* Merge the user-selected arguments with the defaults. */
		$instance = wp_parse_args( (array) $instance, $defaults );
		?>

		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php echo 'Title:'; ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'description' ); ?>"><?php echo 'Description:'; ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'description' ); ?>" name="<?php echo $this->get_field_name( 'description' ); ?>" value="<?php echo esc_attr( $instance['description'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'num' ); ?>"><?php echo 'Number of testimonials to show:'; ?></label>
			<input type="number" step="1" min="1" class="widefat" id="<?php echo $this->get_field_id( 'num' ); ?>" name="<?php echo $this->get_field_name( 'num' ); ?>" value="<?php echo (int) $instance['num']; ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'logos' ); ?>"><?php echo 'Client Logos:'; ?></label>
			<textarea class="widefat" id="<?php echo $this->get_field_id( 'logos' ); ?>" name="<?php echo $this->get_field_name( 'logos' ); ?>" rows="6" ><?php echo stripslashes( $instance['logos'] ); ?></textarea>
		</p>
		
		<?php
	}

}